@@ -1,9 +1,9 @@
 import glob
+import json
 import logging
 import os
 import platform
 import subprocess
-import json
 import tempfile
 import typing
 
@@ -35,6 +35,7 @@ class Session:
         self._current_profile: typing.Optional[typing.Dict] = None
         self._current_info: typing.Optional[typing.Dict] = None
         self._binaries: typing.Dict[str, str] = {}
+        self._custom_libraries: typing.List[typing.Dict[str, str]] = []
         self._logger: logging.Logger = logging.getLogger("PyDelica")
         if log_level == OMLogLevel.DEBUG:
             self._logger.setLevel(logging.DEBUG)
@@ -43,6 +44,22 @@ class Session:
         self._session_directory = os.getcwd()
         self._assert_fail_level = "error"
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args, **kwargs):
+        self._compiler.clear_cache()
+
+    def use_libraries(self, library_specs: typing.List[typing.Dict[str, str]]) -> None:
+        """Use a Modelica library specification list
+
+        Parameters
+        ----------
+        libary_specs : typing.List[typing.Dict[str, str]]
+            list of dictionaries containing version and location info of libraries
+        """
+        self._custom_libraries = library_specs
+
     def use_library(
         self, library_name: str, library_version: str = "", library_directory: str = ""
     ) -> None:
@@ -57,8 +74,12 @@ class Session:
         library_directory : str, optional
             location of library on system, by default OM default paths
         """
-        self._compiler._library.use_library(
-            library_name, library_version, library_directory
+        self._custom_libraries.append(
+            {
+                "name": library_name,
+                "version": library_version,
+                "directory": library_directory,
+            }
         )
 
     def fail_on_assert_level(self, assert_level: str) -> None:
@@ -109,7 +130,7 @@ class Session:
         c_source_dir: str = None,
         profiling: str = None,
         update_input_paths_to: str = None,
-        omc_build_flags: typing.Optional[typing.Dict[str, typing.Optional[str]]] = None
+        omc_build_flags: typing.Optional[typing.Dict[str, typing.Optional[str]]] = None,
     ):
         """Build a Modelica model from a source file
 
@@ -142,11 +163,10 @@ class Session:
 
         self._logger.debug(
             "Building model %sfrom file '%s'",
-            f'{model_addr} ' if model_addr else "",
+            f"{model_addr} " if model_addr else "",
             modelica_source_file,
         )
 
-
         for flag, value in omc_build_flags.items():
             self._compiler.set_omc_flag(flag, value)
 
@@ -157,6 +177,7 @@ class Session:
             model_addr=model_addr,
             extra_models=extra_models,
             c_source_dir=c_source_dir,
+            custom_library_spec=self._custom_libraries,
         )
 
         _xml_files = glob.glob(os.path.join(_binary_loc, "*.xml"))
@@ -166,7 +187,6 @@ class Session:
                 "Failed to retrieve XML files from model compilation"
             )
 
-
         self._logger.debug("Parsing generated XML files")
         for xml_file in _xml_files:
             _model_name = os.path.basename(xml_file).split("_init")[0]
@@ -217,9 +237,8 @@ class Session:
         return self._binaries[model_name]
 
     def get_parameters(
-        self,
-        model_name: str = None
-        ) -> typing.Union[Model, typing.Dict[str, typing.Any]]:
+        self, model_name: str = None
+    ) -> typing.Union[Model, typing.Dict[str, typing.Any]]:
         """Retrieve a full parameter list
 
         Parameters
@@ -420,13 +439,15 @@ class Session:
                 stdout=subprocess.PIPE,
                 text=True,
                 shell=False,
-                cwd=run_dir
+                cwd=run_dir,
             )
 
             pde.parse_error_string_simulate(_run_sim.stdout, self._assert_fail_level)
 
             if _run_sim.returncode != 0:
-                raise pde.OMExecutionError(f"[{_run_sim.returncode}] Simulation failed with:\n{_run_sim.stderr}")
+                raise pde.OMExecutionError(
+                    f"[{_run_sim.returncode}] Simulation failed with:\n{_run_sim.stderr}"
+                )
 
             self._solutions[model_name].retrieve_session_solutions(run_dir)
             self._recover_profile(os.path.dirname(self._binaries[model_name]), run_dir)
