@@ -244,6 +244,11 @@ class Compiler:
                             self._logger.error("Traceback: %s", _gen.stdout)
                         raise e from e
 
+                if _gen.returncode != 0:
+                    raise pde.OMBuildError(
+                        f"Model build configuration failed with exit code {_gen.returncode}:\n\t{_gen.stderr}"
+                    )
+
                 self._logger.debug(_gen.stdout)
 
                 if _gen and _gen.stderr:
@@ -305,9 +310,14 @@ class Compiler:
             if _build.stdout:
                 self._logger.debug(_build.stdout)
 
-            if _gen.stderr:
+            if _build.stderr:
                 self._logger.error(_build.stderr)
 
+            if _build.returncode != 0:
+                raise pde.OMBuildError(
+                    f"Model build failed with exit code {_build.returncode}:\n\t{_build.stderr}"
+                )
+
         self._binary_dirs.append(_temp_build_dir)
 
         return _temp_build_dir
