@@ -147,9 +147,9 @@ class LibrarySetup:
             for library_dir in _library_dirs:
                 _libs += glob.glob(os.path.join(library_dir, "*"))
         elif platform.system() == "Windows":
-            _home = os.environ["HOME"]
+            _home = os.environ["HOMEPATH"]
             _user_libraries = os.path.join(
-                _home, "AppData", "Roaming", ".openmodelica", "libraries"
+                _home, "Users", "AppData", "Roaming", ".openmodelica", "libraries"
             )
             _library_dir = os.path.join(
                 os.environ["OPENMODELICAHOME"], "lib", "omlibrary"
