@@ -8,6 +8,7 @@ import glob
 
 class SolutionHandler:
     """Stores solutions extracted from a Modelica simulation"""
+
     def __init__(self, session_directory: str):
         """Extract solution information from a given session directory
 
@@ -20,9 +21,14 @@ class SolutionHandler:
         self._session_dir = session_directory
         self._solutions: Dict[str, pd.DataFrame] = {}
 
-    def retrieve_session_solutions(self) -> Dict[str, pd.DataFrame]:
+    def retrieve_session_solutions(self, run_directory: str) -> Dict[str, pd.DataFrame]:
         """Retrieve any stored solutions
 
+        Parameters
+        ----------
+        run_directory: str
+            directory containing run outputs
+
         Returns
         -------
         Dict[str, pd.DataFrame]
@@ -33,7 +39,7 @@ class SolutionHandler:
         ResultRetrievalError
             If no CSV result files were found within the session directory
         """
-        _has_csv = glob.glob(os.path.join(self._session_dir, "*.csv"))
+        _has_csv = glob.glob(os.path.join(run_directory, "*.csv"))
 
         if not _has_csv:
             raise ResultRetrievalError
@@ -41,9 +47,7 @@ class SolutionHandler:
         for out_file in _has_csv:
             if "_res" not in out_file:
                 continue
-            self._logger.debug(
-                "Reading results from output file '%s'", out_file
-            )
+            self._logger.debug("Reading results from output file '%s'", out_file)
             _key = out_file.split("_res")[0]
             self._solutions[_key] = pd.read_csv(_has_csv[0])
         return self._solutions
